$OpenBSD: patch-examples_nmapAnswerMachine_py,v 1.1 2014/09/29 08:11:31 dcoppa Exp $
--- examples/nmapAnswerMachine.py.orig	Thu Jul 17 17:39:36 2014
+++ examples/nmapAnswerMachine.py	Thu Sep 25 18:14:30 2014
@@ -14,11 +14,11 @@ from impacket.ImpactPacket import TCPOption
 
 MAC = "01:02:03:04:05:06"
 IP  = "192.168.67.254"
-IFACE = "eth0"
+IFACE = "em0"
 OPEN_TCP_PORTS = [80, 443]
 OPEN_UDP_PORTS = [111]
 UDP_CMD_PORT = 12345
-nmapOSDB = '/usr/share/nmap/nmap-os-db'
+nmapOSDB = '${LOCALBASE}/share/nmap/nmap-os-db'
 
 # Fingerprint = 'Adtran NetVanta 3200 router' # CD=Z TOSI=Z <----------- NMAP detects it as Linux!!!
 # Fingerprint = 'ADIC Scalar 1000 tape library remote management unit' # DFI=S
@@ -1120,4 +1120,4 @@ if __name__ == '__main__':
 # [-] ??? (RUL) Length of return UDP packet is correct
 
 # sudo nmap -O 127.0.0.2 -p 22,111,89
 # sudo python nmapAnswerMachine.py -i eth0 -p 192.168.66.254 -f 'Sun Solaris 9 (SPARC)'
@@ -1120,4 +1120,4 @@ if __name__ == '__main__':
 
 # sudo nmap -O 127.0.0.2 -p 22,111,89
-# sudo python nmapAnswerMachine.py -i eth0 -p 192.168.66.254 -f 'Sun Solaris 9 (SPARC)'
+# sudo python nmapAnswerMachine.py -i em0 -p 192.168.66.254 -f 'Sun Solaris 9 (SPARC)'

